/***************************************************************************
 *   This file is part of KDevelop                                         *
 *   Copyright 2007 Andreas Pakulat <apaku@gmx.de>                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#include "outputmodel.h"

#include <QtCore/QStringList>

#include <kglobalsettings.h>

namespace KDevelop
{

OutputModel::OutputModel( QObject* parent )
    : QStandardItemModel( parent ), d(0)
{

}

void OutputModel::appendLine( const QString& line )
{
    QStandardItem* item = new QStandardItem( line );
    item->setFont( KGlobalSettings::fixedFont() );
    appendRow( item );
}

void OutputModel::appendLines( const QStringList& lines)
{
    Q_FOREACH( const QString& s, lines )
    {
        appendLine( s );
    }
}

}

#include "outputmodel.moc"
